@@ -5,14 +5,14 @@ $self = {
           'typemaps' => [
                           'gtk2perl.typemap',
                           'gdk.typemap',
-                          'gtk.typemap',
-                          'pango.typemap'
+                          'gtk.typemap'
                         ],
           'deps' => [
+                      'Pango',
                       'Glib',
                       'Cairo'
                     ],
-          'libs' => '-L/usr/local/lib -L/usr/X11R6/lib -R/usr/X11R6/lib -lgtk-x11-2.0 -lgdk-x11-2.0 -lgdk_pixbuf-2.0 -lpangocairo-1.0 -lXinerama -lXi -lXrandr -lXcursor -lXcomposite -lXext -lXdamage -lXfixes -latk-1.0 -lcairo -lpixman-1 -lglitz -lpng -lXrender -lXau -lXdmcp -lgio-2.0 -lpangoft2-1.0 -lX11 -lpango-1.0 -lm -lgobject-2.0 -lgmodule-2.0 -lglib-2.0 -lintl -liconv -lfreetype -lz -lfontconfig -lexpat'
+          'libs' => '-L/usr/local/lib -L/usr/X11R6/lib -R/usr/X11R6/lib -lgtk-x11-2.0 -lgdk-x11-2.0 -lgdk_pixbuf-2.0 -lpangocairo-1.0 -lXinerama -lXi -lXrandr -lXcursor -lXcomposite -lXext -lXdamage -lXfixes -latk-1.0 -lcairo -lpixman-1 -lglitz -lpng -lXrender -lXau -lXdmcp -lgio-2.0 -lpangoft2-1.0 -lX11 -lpango-1.0 -lm -lgobject-2.0 -lgmodule-2.0 -lglib-2.0 -lintl -liconv -lfontconfig -lexpat -lfreetype -lz'
         };
 
 
